@@ -22,7 +22,7 @@ class FaultDiagnosis():
     """Class FaultDiagnosis.
 
     Perturbation of a GeneralGraph object.
-    Perturbation can be simulated on a list of elements, or areas.
+    Perturbation can be simulated on a list of elements.
     From one element, the perturbation propagates in all directions,
     unless an isolating element is present.
     """
@@ -44,8 +44,6 @@ class FaultDiagnosis():
             self.G = GeneralGraph()
 
         self.df, self.edges_df = self.G.load(filename)
-
-        self.damaged_areas = set()
         self.paths_df = None
 
     def check_input_with_gephi(self):
@@ -58,8 +56,7 @@ class FaultDiagnosis():
         gephi_nodes_df = self.df.reset_index()
         gephi_nodes_df.rename(columns={'index': 'mark'}, inplace=True)
 
-        fields = [ 'mark', 'description', 'init_status',
-                   'perturbation_resistant', 'area' ]
+        fields = [ 'mark', 'description', 'init_status' ]
         cols_to_str = ['init_status']
         gephi_nodes_df[cols_to_str] = gephi_nodes_df[cols_to_str].astype(str)
         conversions = {'nan': '', '1.0': '1', '0.0': '0'}
@@ -73,7 +70,7 @@ class FaultDiagnosis():
         self.edges_df.to_csv('check_import_edges.csv', index=False)
 
     def fitness_iteration_parallel(self, out_queue, ichunk, chunk_length,
-        individuals, perturbed_nodes, initial_condition, origin):
+        individuals, perturbed_nodes, initial_condition):
         """
 
         Parallel iteration for fitness evaluation. We append to the
@@ -90,19 +87,16 @@ class FaultDiagnosis():
         :param list perturbed_nodes: nodes(s) involved in the perturbing event.
         :param dict initial_condition: initial status (boolean) for the graph
             switches.
-        :param origin: origin of the perturbation. Nodes can be resitant to
-            different kinds of perturbations, default to None.
-        :type origin: string, optional
         """
 
         for idx, item in enumerate(individuals):
             ind_fit = (ichunk*chunk_length + idx, item,
                 self.fitness_evaluation(item, perturbed_nodes,
-                initial_condition, origin))
+                initial_condition))
             out_queue.put(ind_fit)
 
     def fitness_evaluation_parallel(self, pop, perturbed_nodes,
-        initial_condition, origin):
+        initial_condition):
         """
 
         Wrapper for fitness evaluation. This methods spawns the processes for
@@ -112,9 +106,6 @@ class FaultDiagnosis():
         :param list perturbed_nodes: nodes(s) involved in the perturbing event.
         :param dict initial_condition: initial status (boolean) for the graph
             switches.
-        :param origin: origin of the perturbation. Nodes can be resitant to
-            different kinds of perturbations, default to None.
-        :type origin: string, optional
 
         :return: list of tuples constituted by the index of the individual,
             the individual itself, and its fitness.
@@ -130,7 +121,7 @@ class FaultDiagnosis():
         processes = [
             mp.Process( target=self.fitness_iteration_parallel,
             args=( out_queue, p, len(ind_chunks[0]), ind_chunks[p],
-                perturbed_nodes, initial_condition, origin ))
+                perturbed_nodes, initial_condition ))
                 for p in range(n_procs) ]
 
         for proc in processes:
@@ -148,7 +139,7 @@ class FaultDiagnosis():
         return fitnesses_tuples
 
     def fitness_evaluation(self, individual, perturbed_nodes,
-        initial_condition, origin):
+        initial_condition):
         """
 
         Evaluation of fitness on individual.
@@ -162,9 +153,6 @@ class FaultDiagnosis():
             perturbing event.
         :param dict initial_condition: initial status (boolean) for the graph
             switches.
-        :param origin: origin of the perturbation. Nodes can be resitant to
-            different kinds of perturbations, default to None.
-        :type origin: string, optional
         """
 
         acts = np.sum(np.not_equal(list(initial_condition.values()),
@@ -173,12 +161,9 @@ class FaultDiagnosis():
         T = GeneralGraph()
         T.add_nodes_from(self.G)
         for (u, v, d) in self.G.edges(data=True):
-            T.add_edge(u, v, father_condition=d['father_condition'],
-                weight=d['weight'])
+            T.add_edge(u, v, weight=d['weight'])
         nx.set_node_attributes(T, self.G.initial_service,
             name='initial_service')
-        nx.set_node_attributes(T, self.G.perturbation_resistant,
-            name='perturbation_resistant')
         nx.set_node_attributes(T, self.G.type, name='type')
 
         for switch, status in zip(initial_condition.keys(), individual):
@@ -189,7 +174,7 @@ class FaultDiagnosis():
         for node in perturbed_nodes:
             if node in T.nodes():
 
-                _, broken_nodes = self.rm_nodes(node, T, origin)
+                _, broken_nodes = self.rm_nodes(node, T)
                 broken_nodes = list(set(broken_nodes))
 
                 for n in broken_nodes:
@@ -209,7 +194,7 @@ class FaultDiagnosis():
             len(usr_with_serv.keys()), sum(dist_from_avg.values()))
 
     def optimizer(self, perturbed_nodes, initial_condition, params, weights,
-        parallel, origin):
+        parallel):
         """
 
         Genetic algorithm to optimize switches conditions, using DEAP.
@@ -228,7 +213,7 @@ class FaultDiagnosis():
             - 'nsel': number of individuals to select (default to 5)
         :param dict weights: weights for fitness evaluation on individuals.
             Dict of: {str: float, str: float, str: float}:
-            - 'w1': weight multiplying number of actions (default to 1.0)
+            - 'w1': weight multiplying number of switch flips (default to 1.0)
             - 'w2': weight multiplying total final service (default to -1.0)
             - 'w3': weight multiplying final graph size (default to -1.0)
             - 'w4': weight multiplying number of users with non-zero service
@@ -236,9 +221,6 @@ class FaultDiagnosis():
             - 'w5': weight for service balance over users (default to 2.0)
         :param bool parallel: flag for parallel fitness evaluation of
             initial populations.
-        :param origin: origin of the perturbation. Nodes can be resitant to
-            different kinds of perturbations, default to None.
-        :type origin: string, optional
         """
 
         logging.getLogger().setLevel(logging.INFO)
@@ -265,10 +247,10 @@ class FaultDiagnosis():
         # Evaluate the entire population
         if (not parallel) or (len(pop) < mp.cpu_count()):
             fitnesses = [toolbox.evaluate(ind, perturbed_nodes,
-                initial_condition, origin) for ind in pop]
+                initial_condition) for ind in pop]
         else:
             res_par = self.fitness_evaluation_parallel(pop, perturbed_nodes,
-                initial_condition, origin)
+                initial_condition)
             res_par.sort(key=lambda x:x[0])
             fitnesses = [x[2] for x in res_par]
 
@@ -313,10 +295,10 @@ class FaultDiagnosis():
             # Evaluate the individuals with an invalid fitness
             if (not parallel) or (len(invalid_ind) < mp.cpu_count()):
                 fitnesses = [toolbox.evaluate(ind, perturbed_nodes,
-                    initial_condition, origin) for ind in invalid_ind]
+                    initial_condition) for ind in invalid_ind]
             else:
                 res_par = self.fitness_evaluation_parallel(invalid_ind,
-                    perturbed_nodes, initial_condition, origin)
+                    perturbed_nodes, initial_condition)
                 res_par.sort(key=lambda x:x[0])
                 fitnesses = [x[2] for x in res_par]
 
@@ -380,7 +362,6 @@ class FaultDiagnosis():
 
                 source_user_paths.append({
                     'from': source,
-                    'area': self.G.area[source],
                     'to': user,
                     str(prefix + 'shortest_path_length'): shpath_length,
                     str(prefix + 'shortest_path'): shpath,
@@ -395,21 +376,16 @@ class FaultDiagnosis():
                 self.paths_df = df
             else:
                 self.paths_df = pd.merge(self.paths_df, df,
-                    on=['from', 'to', 'ids', 'area'], how='outer')
+                    on=['from', 'to', 'ids'], how='outer')
 
-    def rm_nodes(self, node, graph, origin, visited=None, broken_nodes=None):
+    def rm_nodes(self, node, graph, visited=None, broken_nodes=None):
         """
 
         Remove nodes from the graph in a depth first search way to
         propagate the perturbation.
-        Nodes are not deleted if at the beginning of the cascade, when resistant
-        to the origin of the perturbation.
 
         :param str node: the id of the node to remove.
         :param nx.DiGraph graph: graph on which to apply the node deletion
-        :param origin: origin of the perturbation. Nodes can be resitant to
-            different kinds of perturbations, default to None.
-        :type origin: string, optional
         :param visited: nodes already visited, default to None.
         :type visited: set, optional
         :param broken_nodes: nodes that got broken along the perturbation,
@@ -424,51 +400,11 @@ class FaultDiagnosis():
         logging.debug('Visited: %s', visited)
         logging.debug('Node: %s', node)
 
-        if origin in graph.perturbation_resistant[node] and len(visited) == 1:
-            logging.debug('Node %s visited, fault resistant node', node)
-            logging.debug('Perturbation origin: %s', origin)
-            return visited, broken_nodes
-
-        fathers = {'AND': set(), 'OR': set(), 'SINGLE': set() }
-        predecessors = list(graph.predecessors(node))
-        logging.debug('Predecessors: %s', predecessors)
-
-        if len(visited) == 1:
-            broken_nodes.append(node)
-            logging.debug('Broken: %s', broken_nodes)
-
-        elif predecessors:
-            for p in predecessors:
-                fathers[graph.father_condition[(p, node)]].add(p)
-
-            if fathers['AND'] & set(broken_nodes):
-                broken_nodes.append(node)
-                logging.debug('Broken %s, AND predecessor broken.', node)
-                logging.debug('Nodes broken so far: %s', broken_nodes)
-
-            #'SINGLE' treated as 'AND'
-            elif fathers['SINGLE'] & set(broken_nodes):
-                broken_nodes.append(node)
-                logging.debug('Broken %s, SINGLE predecessor broken.', node)
-                logging.debug('Nodes broken so far: %s', broken_nodes)
-
-            else:
-                if (fathers['OR'] & set(broken_nodes)) == set(predecessors):
-                    #all my 'OR' predecessors are dead
-                    broken_nodes.append(node)
-                    logging.debug('Broken %s, no more fathers', node)
-                    logging.debug('Nodes broken so far: %s', broken_nodes)
-                else:
-                    logging.debug('Surviving fathers: %s', fathers)
-                    logging.debug('Nodes broken so far: %s', broken_nodes)
-                    return 0
-        else:
-            broken_nodes.append(node)
-            logging.debug('Node: %s has no more predecessors', node)
-            logging.debug('Nodes broken so far: %s', broken_nodes)
+        broken_nodes.append(node)
+        logging.debug('Nodes broken so far: %s', broken_nodes)
 
         for next_node in set(graph[node]) - visited:
-            self.rm_nodes(next_node, graph, origin, visited, broken_nodes)
+            self.rm_nodes(next_node, graph, visited, broken_nodes)
 
         return visited, broken_nodes
 
@@ -488,43 +424,18 @@ class FaultDiagnosis():
         for col in attribute_list:
             self.df[prefix + col] = pd.Series(getattr(self.G, col))
 
-    def update_status_areas(self, damaged_areas):
-        """
-
-        Update the status of the elements in the damaged areas
-        after the propagation of the perturbation.
-
-        :param list damaged_areas: area(s) in which to update the status.
-        """
-
-        self.df['mark_status'].fillna('NOT_ACTIVE', inplace=True)
-
-        old_status_area = self.G.status_area
-        new_status_area = old_status_area
-        for node in old_status_area.keys():
-            if self.G.area[node] in damaged_areas:
-                new_status_area[node] = 'DAMAGED'
-
-        self.G.status_area = new_status_area
-
-        for area in damaged_areas:
-            self.df.loc[self.df.area == area, 'status_area'] = 'DAMAGED'
-
-    def delete_a_node(self, node, origin):
+    def delete_a_node(self, node):
         """
 
         Delete a node in the graph.
 
         :param str node: the id of the node to remove.
-        :param origin: origin of the perturbation. Nodes can be resitant to
-            different kinds of perturbations, default to None.
-        :type origin: string, optional
 
         .. warning:: the node id must be contained in the graph.
             No check is done within this function.
         """
 
-        _ , broken_nodes = self.rm_nodes(node, self.G, origin)
+        _ , broken_nodes = self.rm_nodes(node, self.G)
         broken_nodes = list(set(broken_nodes))
         self.G._del_nodes.extend(broken_nodes)
 
@@ -534,11 +445,10 @@ class FaultDiagnosis():
             data=True)))
 
         for n in broken_nodes:
-            self.damaged_areas.add(self.G.area[n])
             self.G.remove_node(n)
 
     def apply_perturbation(self, perturbed_nodes, params, weights, parallel,
-        verbose, origin, kind='element'):
+        verbose, kind='element'):
         """
 
         Perturbation simulator, actually applying the perturbation
@@ -559,7 +469,7 @@ class FaultDiagnosis():
             - 'nsel': number of individuals to select (default to 5)
         :param dict weights: weights for fitness evaluation on individuals.
             Dict of: {str: float, str: float, str: float}:
-            - 'w1': weight multiplying number of actions (default to 1.0)
+            - 'w1': weight multiplying number of switch flips (default to 1.0)
             - 'w2': weight multiplying total final service (default to -1.0)
             - 'w3': weight multiplying final graph size (default to -1.0)
             - 'w4': weight multiplying number of users with non-zero service
@@ -568,26 +478,24 @@ class FaultDiagnosis():
         :param bool parallel: flag for parallel fitness evaluation of
             initial population.
         :param bool verbose: flag for verbose printing.
-        :param origin: origin of the perturbation. Nodes can be resitant to
-            different kinds of perturbations, default to None.
-        :type origin: string, optional
         :param str kind: type of simulation, used to label output files,
             default to 'element'.
 
         .. note:: A perturbation, depending on the considered system,
             may spread in all directions starting from the damaged
-            component(s) and may be affect nearby areas.
+            component(s) and may be affect nearby elements.
         """
 
         if self.G.switches:
 
             res = self.optimizer(perturbed_nodes, self.G.init_status, params,
-                weights, parallel, origin)
+                weights, parallel)
             w = np.asarray(list(weights.values()))
 
             if verbose:
                 with open('results_generations.dat', 'w', encoding='utf8') as f:
                     for r in res:
+                        f.write(f'{self.G.init_status.items()}')
                         f.write(f'{r[0]} {r[1]}')
                         fit = np.dot(w, np.asarray(r[1]))
                         f.write(f'{fit}\n')
@@ -636,32 +544,33 @@ class FaultDiagnosis():
                             self.G.add_edge(pre, sw, **attrs)
 
             print(f'\nBEST: {best}')
-            print(f'Number of actions: {res[0][1][0]}')
+            print(f'Number of switch flips: {res[0][1][0]}')
             print(f'Total final service: {res[0][1][1]}')
             print(f'Number of survived nodes: {res[0][1][2]}')
             print(f'Number of users with non-zero service: {res[0][1][3]}')
             print(f'Distance from average: {res[0][1][4]}')
             fit = np.dot(w, np.asarray(res[0][1]))
+            print(f'\nFor a final loss of: {fit}\n')
             self.G.final_status = best
 
         for node in perturbed_nodes:
+            print(f'Perturbed nodes: {perturbed_nodes}')
             if node in self.G.nodes():
-                self.delete_a_node(node, origin)
+                self.delete_a_node(node)
 
         self.check_paths_and_measures(prefix='final_')
         self.paths_df.to_csv('service_paths_' + str(kind)+ '_perturbation.csv',
             index=False)
 
-        status_area_fields = ['final_status', 'mark_status', 'status_area']
-        self.update_output(status_area_fields)
+        status_fields = ['final_status', 'mark_status']
+        self.update_output(status_fields)
 
-        self.update_status_areas(self.damaged_areas)
         self.graph_characterization_to_file(str(kind) + '_perturbation.csv')
 
     def simulate_element_perturbation(self, perturbed_nodes,
         params={'npop': 300, 'ngen': 100, 'indpb': 0.6, 'tresh': 0.5,
         'nsel': 5}, weights={'w1': 1.0, 'w2': -1.0, 'w3': -1.0, 'w4': -1.0,
-        'w5': 2.0}, parallel=False, verbose=True, origin=None):
+        'w5': 2.0}, parallel=False, verbose=True):
         """
 
         Simulate a perturbation of one or multiple nodes.
@@ -679,7 +588,7 @@ class FaultDiagnosis():
         :type params: dict, optional
         :param weights: weights for fitness evaluation on individuals.
             Dict of: {str: float, str: float, str: float}:
-            - 'w1': weight multiplying number of actions (default to 1.0)
+            - 'w1': weight multiplying number of switch flips (default to 1.0)
             - 'w2': weight multiplying total final service (default to -1.0)
             - 'w3': weight multiplying final graph size (default to -1.0)
             - 'w4': weight multiplying number of users with non-zero service
@@ -691,13 +600,11 @@ class FaultDiagnosis():
         :type parallel: bool, optional
         :param verbose: flag for verbose output, default to True.
         :type verbose: bool, optional
-        :param origin: origin of the perturbation. Nodes can be resitant to
             different kinds of perturbations, default to None.
-        :type origin: string, optional
 
         .. note:: A perturbation, depending on the considered system,
             may spread in all directions starting from the damaged
-            component(s) and may be affect nearby areas.
+            component(s) and may be affect nearby elements.
 
         :raises: SystemExit
         """
@@ -711,66 +618,7 @@ class FaultDiagnosis():
                 sys.exit()
 
         self.apply_perturbation(perturbed_nodes, params, weights, parallel,
-            verbose, origin, kind='element')
-
-    def simulate_area_perturbation(self, perturbed_areas, params={'npop': 300,
-        'ngen': 100, 'indpb': 0.6, 'tresh': 0.5, 'nsel': 5},
-        weights={'w1': 1.0, 'w2': -1.0, 'w3': -1.0, 'w4': -1.0, 'w5': 2.0},
-        parallel=False, verbose=True, origin=None):
-        """
-
-        Simulate a perturbation in one or multiple areas.
-
-        :param list perturbed_areas: area(s) involved in the perturbing event.
-        :param dict params: values for the optimizer evolutionary algorithm.
-            Dict of: {str: int, str: int, str: float, str: float, str: int}:
-            - 'npop': number of individuals for each population (default to 300)
-            - 'ngen': total number of generations (default to 100)
-            - 'indpb': independent probability for attributes to be changed
-            (default to 0.6)
-            - 'tresh' threshold for applying crossover/mutation
-            (default to 0.5)
-            - 'nsel': number of individuals to select (default to 5)
-        :type params: dict, optional
-        :param weights: weights for fitness evaluation on individuals.
-            Dict of: {str: float, str: float, str: float}:
-            - 'w1': weight multiplying number of actions (default to 1.0)
-            - 'w2': weight multiplying total final service (default to -1.0)
-            - 'w3': weight multiplying final graph size (default to -1.0)
-            - 'w4': weight multiplying number of users with non-zero service
-                (default to -1.0)
-            - 'w5': weight for service balance over users (default to 2.0)
-        :type weights: dict, optional
-        :param parallel: flag for parallel fitness evaluation of
-            initial population, default to False.
-        :type parallel: bool, optional
-        :param origin: origin of the perturbation. Nodes can be resitant to
-            different kinds of perturbations, default to None.
-        :type origin: string, optional
-
-        .. note:: A perturbation, depending on the considered system,
-            may spread in all directions starting from the damaged
-            component(s) and may be affect nearby areas.
-
-        :raises: SystemExit
-        """
-
-        nodes_in_area = []
-
-        for area in perturbed_areas:
-
-            if area not in list(self.G.area.values()):
-                logging.debug('The area %s is not in the graph', area)
-                logging.debug('Insert a valid area')
-                logging.debug('Valid areas: %s', set(self.G.area.values()))
-                sys.exit()
-            else:
-                for idx, idx_area in self.G.area.items():
-                    if idx_area == area:
-                        nodes_in_area.append(idx)
-
-        self.apply_perturbation(nodes_in_area, params, weights, parallel,
-            verbose, origin, kind='area')
+            verbose, kind='element')
 
     def graph_characterization_to_file(self, filename):
         """
@@ -786,8 +634,7 @@ class FaultDiagnosis():
         self.df.rename(columns={'index': 'mark'}, inplace=True)
 
         fields = [
-            'mark', 'description', 'init_status', 'final_status',
-            'mark_status', 'perturbation_resistant', 'area', 'status_area',
+            'mark', 'description', 'init_status', 'final_status', 'mark_status',
             'original_closeness_centrality', 'final_closeness_centrality',
             'original_betweenness_centrality', 'final_betweenness_centrality',
             'original_indegree_centrality', 'final_indegree_centrality',
