@@ -7,8 +7,6 @@ import copy
 import numpy as np
 import networkx as nx
 import pandas as pd
-from matplotlib import cm
-from matplotlib.colors import ListedColormap
 import matplotlib.lines as mlines
 import matplotlib.pyplot as plt
 
@@ -42,16 +40,15 @@ class GeneralGraph(nx.DiGraph):
 
         :param str filename: input file in CSV format.
 
-        :return: DataFrame containing the following attributes: mark, area,
-            perturbation_resistant, init_status, description;
+        :return: DataFrame containing the following attributes: mark,
+            init_status, description;
             DataFrame containing mark and father_mark attribute.
         :rtype: pandas.DataFrame, pandas.DataFrame
         """
 
-        conv = {'mark' : str, 'father_mark' : str,
-            'perturbation_resistant' : str}
+        conv = {'mark' : str, 'father_mark' : str}
         graph_df = pd.read_csv(filename, converters=conv, keep_default_na=False)
-        cols_to_num = ['init_status']
+        cols_to_num = ['init_status', 'initial_service']
         graph_df[cols_to_num] = graph_df[cols_to_num].apply(pd.to_numeric,
             errors='coerce', axis=1)
 
@@ -59,34 +56,24 @@ class GeneralGraph(nx.DiGraph):
 
             edge_weight = row.pop('weight')
             father_mark = row.pop('father_mark')
-            edge_father_condition = row.pop('father_condition')
 
             self.add_node(row['mark'], **row)
 
             if father_mark != 'NULL':
                 self.add_edge(
                     father_mark, row['mark'],
-                    father_condition=edge_father_condition,
                     weight=edge_weight)
 
         graph_edges_df = graph_df[['mark', 'father_mark']]
 
-        graph_df.drop(['father_condition', 'father_mark', 'type',
-                      'weight', 'initial_service'], axis=1, inplace=True)
+        graph_df.drop(['father_mark', 'type', 'weight', 'initial_service'],
+            axis=1, inplace=True)
         graph_df.drop_duplicates(inplace=True)
         graph_df.set_index('mark', inplace=True)
 
         self._final_status = {}
-        nx.set_node_attributes(self, 'AVAILABLE', name='status_area')
         nx.set_node_attributes(self, 'ACTIVE', name='mark_status')
 
-        perts = nx.get_node_attributes(self, 'perturbation_resistant')
-        split_perts = {node: perts[node].split("/")
-            for node in self.nodes}
-        strip_perts = {node: [x.strip() for x in split_perts[node]]
-            for node in self.nodes}
-        nx.set_node_attributes(self, strip_perts, name='perturbation_resistant')
-
         return graph_df, graph_edges_df
 
     @property
@@ -98,26 +85,6 @@ class GeneralGraph(nx.DiGraph):
         """
         return nx.get_node_attributes(self, 'mark')
 
-    @property
-    def area(self):
-        """
-
-        :return: area attribute for every node.
-        :rtype: dict
-        """
-
-        return nx.get_node_attributes(self, 'area')
-
-    @property
-    def perturbation_resistant(self):
-        """
-
-        :return: perturbation_resistant attribute for every node.
-        :rtype: dict
-        """
-
-        return nx.get_node_attributes(self, 'perturbation_resistant')
-
     @property
     def description(self):
         """
@@ -172,36 +139,6 @@ class GeneralGraph(nx.DiGraph):
 
         return nx.get_node_attributes(self, 'mark_status')
 
-    @property
-    def status_area(self):
-        """
-
-        :return: status_area attribute for every node.
-        :rtype: dict
-        """
-
-        return nx.get_node_attributes(self, 'status_area')
-
-    @status_area.setter
-    def status_area(self, status_area_dict):
-        """
-
-        :param dict status_area_dict: dictionary keyed by node,
-            containing the values for status_area attribute.
-        """
-
-        nx.set_node_attributes(self, status_area_dict, name='status_area')
-
-    @property
-    def father_condition(self):
-        """
-
-        :return: father_condition attribute for every edge.
-        :rtype: dict
-        """
-
-        return nx.get_edge_attributes(self, 'father_condition')
-
     @property
     def weight(self):
         """
@@ -1251,7 +1188,7 @@ class GeneralGraph(nx.DiGraph):
 
     def print_graph(self, radius=None, initial_pos=None, fixed_nodes=None,
         n_iter=500, thresh=0.0001, size=800, border='black', edge_width=1.0,
-        arrow_size=10, fsize=12, fcolor='k', title='Graph', input_cmap=None,
+        arrow_size=10, fsize=12, fcolor='k', title='Graph',
         legend=True, legend_loc='upper right', legend_ncol=1,
         legend_anchor=None, legend_fsize=12, save_to_file=None, status=None):
         """
@@ -1264,12 +1201,6 @@ class GeneralGraph(nx.DiGraph):
         a subset of the nodes.
         The shapes of the nodes characterize their type
         (SOURCE/HUB/USER/SWITCH).
-        Nodes color is set as white with black borders by default. If an input
-        colormap is specified, different areas get colored differently (the
-        colormap is evenly spaced in color depending on the total number of
-        areas).
-        Edges are colored depending on the logic relation specified: black for
-        SINGLE edges, magenta for AND edges, brown dashed for OR edges.
         The font size, family and color for labels can be also specified,
         together with the title for the window figure.
 
@@ -1306,10 +1237,6 @@ class GeneralGraph(nx.DiGraph):
         :type fcolor: string, optional
         :param title: title for figure window, default to 'Graph'.
         :type title: string, optional
-        :param input_cmap: colormap for coloring the different areas with
-            different colors, default to None.
-            If None, all nodes are colored as white.
-        :type input_cmap: Matplotlib colormap
         :param legend: show the legend on/off, default to True.
         :type legend: bool, optional
         :param legend_loc: the location of the legend, default to 'upper right'.
@@ -1345,8 +1272,8 @@ class GeneralGraph(nx.DiGraph):
 
         T = copy.deepcopy(self)
 
-        T.add_nodes_from(self._del_nodes)
-        T.add_edges_from(self._del_edges)
+        #T.add_nodes_from(self._del_nodes)
+        #T.add_edges_from(self._del_edges)
 
         pos = nx.spring_layout(T, k=radius, pos=initial_pos,
             fixed=fixed_nodes, iterations=n_iter, threshold=thresh,
@@ -1354,55 +1281,22 @@ class GeneralGraph(nx.DiGraph):
 
         shapes = {'SOURCE': 'v', 'USER': '^', 'HUB': 'o', 'SWITCH': 'X'}
 
-        all_areas = list(set(self.area.values()))
-        if input_cmap is None:
-            mymap = ListedColormap(["white"])
-        else:
-            mymap = cm.get_cmap(input_cmap, len(all_areas))
-        area_indices = {}
-        for idx, item in enumerate(all_areas):
-            area_indices[item] = idx*(1./len(all_areas))
-
         for node in self:
-            col = mymap(area_indices[self.area[node]])
-            col = np.array([col])
-            nx.draw_networkx_nodes(T, pos, nodelist=[node], node_color=col,
+            nx.draw_networkx_nodes(T, pos, nodelist=[node],
                 node_shape=shapes[self.type[node]], node_size=size,
                 edgecolors=border, alpha=0.5)
 
-        pert_resistant = [node for node in self.perturbation_resistant.keys()
-             if self.perturbation_resistant[node][0]]
+        #if self._del_nodes:
+        #    del_marks = {n: n for n in self._del_nodes}
+        #    for node in self._del_nodes:
+        #        nx.draw_networkx_nodes(T, pos, nodelist=[node],
+        #            node_color='white', node_shape='.',
+        #            node_size=size, edgecolors='white', alpha=1.0)
+        #    nx.draw_networkx_labels(T, pos, labels=del_marks,
+        #        font_size=fsize, font_color='red')
 
-        for node in pert_resistant:
-            col = mymap(area_indices[self.area[node]])
-            col = np.array([col])
-            nx.draw_networkx_nodes(T, pos, nodelist=[node], node_color=col,
-                node_shape=shapes[self.type[node]], node_size=size,
-                edgecolors=border, alpha=1.0)
-
-        if self._del_nodes:
-            del_marks = {n: n for n in self._del_nodes}
-            for node in self._del_nodes:
-                nx.draw_networkx_nodes(T, pos, nodelist=[node],
-                    node_color='white', node_shape='.',
-                    node_size=size, edgecolors='white', alpha=1.0)
-            nx.draw_networkx_labels(T, pos, labels=del_marks,
-                font_size=fsize, font_color='red')
-
-        or_edges = [(u, v) for (u, v, d) in self.edges(data=True)
-            if d['father_condition'] == 'OR']
-        and_edges = [(u, v) for (u, v, d) in self.edges(data=True)
-            if d['father_condition'] == 'AND']
-        single_edges = [(u, v) for (u, v, d) in self.edges(data=True)
-            if d['father_condition'] == 'SINGLE']
-
-        #deleted edges
-        or_edges_del = [(u, v) for (u, v, d) in self._del_edges
-            if d['father_condition'] == 'OR']
-        and_edges_del = [(u, v) for (u, v, d) in self._del_edges
-            if d['father_condition'] == 'AND']
-        single_edges_del = [(u, v) for (u, v, d) in self._del_edges
-            if d['father_condition'] == 'SINGLE']
+        edges = [(u, v) for (u, v, d) in self.edges(data=True)]
+        #edges_del = [(u, v) for (u, v, d) in self._del_edges]
 
         if status == 'initial':
             status_sw = [k for k, v in self.init_status.items() if not v]
@@ -1411,29 +1305,15 @@ class GeneralGraph(nx.DiGraph):
                 for pred in list(self.predecessors(sw)):
                     edges_no_init.append((pred,sw))
 
-            or_edges = list(set(or_edges)-set(edges_no_init))
-            and_edges = list(set(and_edges)-set(edges_no_init))
-            single_edges = list(set(single_edges)-set(edges_no_init))
+            edges = list(set(edges)-set(edges_no_init))
 
-        nx.draw_networkx_edges(T, pos, edgelist=or_edges, width=edge_width,
-            arrowsize=arrow_size, alpha=0.9, edge_color='brown', style='dashed',
-            node_size=size)
-        nx.draw_networkx_edges(T, pos, edgelist=and_edges, width=edge_width,
-            arrowsize=arrow_size, alpha=0.9, edge_color='violet',
-            node_size=size)
-        nx.draw_networkx_edges(T, pos, edgelist=single_edges,
+        nx.draw_networkx_edges(T, pos, edgelist=edges,
             width=edge_width, arrowsize=arrow_size, alpha=0.9,
             edge_color='black', node_size=size)
 
-        nx.draw_networkx_edges(T, pos, edgelist=or_edges_del,
-            width=(edge_width/2.), arrowsize=arrow_size, alpha=0.9,
-            edge_color='red', style='dashed', node_size=size)
-        nx.draw_networkx_edges(T, pos, edgelist=and_edges_del,
-            width=(edge_width/2.), arrowsize=arrow_size, alpha=0.9,
-            edge_color='red', node_size=size)
-        nx.draw_networkx_edges(T, pos, edgelist=single_edges_del,
-            width=(edge_width/2.), arrowsize=arrow_size, alpha=0.9,
-            edge_color='red', node_size=size)
+        #nx.draw_networkx_edges(T, pos, edgelist=edges_del,
+        #    width=(edge_width/2.), arrowsize=arrow_size, alpha=0.9,
+        #    edge_color='red', node_size=size)
 
         nx.draw_networkx_labels(T, pos, labels=self.mark, font_size=fsize,
             font_color=fcolor)
@@ -1461,37 +1341,26 @@ class GeneralGraph(nx.DiGraph):
             markeredgecolor='black', markersize=legend_fsize, linewidth=0.0,
             label='SWITCH')
         handles.append(switch_key)
-        pr_key = mlines.Line2D([], [], color='black', alpha=1.0, marker='o',
-            markeredgecolor='black', markersize=legend_fsize, linewidth=0.0,
-            label='Perturbation Resistant')
-        handles.append(pr_key)
-        del_node_key = mlines.Line2D([], [], color='red', alpha=1.0, marker='.',
-            markeredgecolor='white', markersize=legend_fsize, linewidth=0.0,
-            label='Broken node')
-        handles.append(del_node_key)
+        #del_node_key = mlines.Line2D([], [], color='red', alpha=1.0,marker='.',
+        #    markeredgecolor='white', markersize=legend_fsize, linewidth=0.0,
+        #    label='Broken node')
+        #handles.append(del_node_key)
 
-        single_key = mlines.Line2D([], [], color='white',
+        edge_key = mlines.Line2D([], [], color='white',
             marker=r'$\rightarrow$', markeredgecolor='black',
-            markersize=legend_fsize, label='SINGLE')
-        handles.append(single_key)
-        or_key = mlines.Line2D([], [], color='white',
-            marker=r'$-\rightarrow$', markeredgecolor='brown',
-            markersize=legend_fsize, label='OR')
-        handles.append(or_key)
-        and_key = mlines.Line2D([], [], color='white',
-            marker=r'$\rightarrow$', markeredgecolor='violet',
-            markersize=legend_fsize, label='AND')
-        handles.append(and_key)
-        del_edge_key = mlines.Line2D([], [], color='white',
-            marker=r'$\rightarrow$', markeredgecolor='red',
-            markersize=legend_fsize, label='Broken edge')
-        handles.append(del_edge_key)
+            markersize=legend_fsize, label='EDGE')
+        handles.append(edge_key)
+        #del_edge_key = mlines.Line2D([], [], color='white',
+        #    marker=r'$\rightarrow$', markeredgecolor='red',
+        #    markersize=legend_fsize, label='Broken edge')
+        #handles.append(del_edge_key)
 
         if legend:
             plt.legend(handles=handles, loc=legend_loc, ncol=legend_ncol,
             bbox_to_anchor=legend_anchor, fontsize=legend_fsize)
 
         if save_to_file:
+            plt.rcParams["text.usetex"] = False
             plt.savefig(save_to_file, orientation='landscape', transparent=True)
         else:
             plt.show()
