@@ -7,10 +7,8 @@ from multiprocessing import Queue
 import multiprocessing as mp
 from multiprocessing.sharedctypes import RawArray
 import ctypes
-import copy
 import numpy as np
 import networkx as nx
-import pandas as pd
 
 from .utils import chunk_it
 from .general_graph import GeneralGraph
@@ -48,7 +46,7 @@ class ParallelGeneralGraph(GeneralGraph):
         :param multiprocessing.managers.dict record:
             shared dictionary to be updated.
         :param callable kernel: kernel measure to be computed.
-        :param \*measure_args: arguments for kernel measures.
+        :param *measure_args: arguments for kernel measures.
            Have a look at specific kernel measures in GeneralGraph for
            the particular variables/types for each measure.
         """
@@ -66,7 +64,7 @@ class ParallelGeneralGraph(GeneralGraph):
         :param multiprocessing.managers.dict record:
             shared dictionary to be updated
         :param callable kernel: kernel measure to be computed
-        :param \*measure_args: arguments for kernel measures
+        :param *measure_args: arguments for kernel measures
            (have a look at specific kernel measures in GeneralGraph
            for the particular variables/types for each measure)
         """
@@ -164,7 +162,7 @@ class ParallelGeneralGraph(GeneralGraph):
                 length_path = dist_shared[self.ids_reversed[value[0]],
                                           self.ids_reversed[value[-1]]]
                 shortest_path_length[self.ids[i]][key] = length_path
-        
+
         return nonempty_shortest_path, shortest_path_length
 
     def dijkstra_iteration_parallel(self, out_queue, nodes):
@@ -205,10 +203,8 @@ class ParallelGeneralGraph(GeneralGraph):
         :rtype: dict, dict
         """
 
-        self.attribute_ssspp = []
-
+        attribute_ssspp = []
         out_queue = Queue()
-
         node_chunks = chunk_it(list(self.nodes()), self.num)
 
         processes = [
@@ -223,14 +219,14 @@ class ParallelGeneralGraph(GeneralGraph):
             running = any(p.is_alive() for p in processes)
             while not out_queue.empty():
 
-                self.attribute_ssspp.append(out_queue.get())
+                attribute_ssspp.append(out_queue.get())
 
             if not running:
                 break
 
         shortest_path = {}
         shortest_path_length = {}
-        for ssspp in self.attribute_ssspp:
+        for ssspp in attribute_ssspp:
 
             n = ssspp[0]
             shortest_path[n] = ssspp[1][1]
@@ -261,14 +257,14 @@ class ParallelGeneralGraph(GeneralGraph):
         n_of_nodes = self.order()
         graph_density = nx.density(self)
 
-        logging.debug(f'Number of processors: {self.num}')
+        logging.debug('Number of processors: %s', self.num)
 
-        logging.debug(f'In the graph are present {n_of_nodes} nodes')
+        logging.debug('In the graph are present %s nodes', n_of_nodes)
         if graph_density <= 0.000001:
-            logging.debug(f'The graph is sparse, density = {graph_density}')
+            logging.debug('The graph is sparse, density = %s', graph_density)
             shpath, shpath_len = self.dijkstra_single_source_shortest_path()
         else:
-            logging.debug(f'The graph is dense, density = {graph_density}')
+            logging.debug('The graph is dense, density = %s', graph_density)
             shpath, shpath_len = self.floyd_warshall_predecessor_and_distance()
 
         return shpath, shpath_len
@@ -290,7 +286,7 @@ class ParallelGeneralGraph(GeneralGraph):
 
         shortest_path_length = self.shortest_path_length
         efficiency = self.manager.dict()
-        self.measure_processes(efficiency, self.efficiency_kernel, 
+        self.measure_processes(efficiency, self.efficiency_kernel,
             shortest_path_length)
         return efficiency
 
@@ -333,7 +329,7 @@ class ParallelGeneralGraph(GeneralGraph):
 
         nodal_efficiency = self.nodal_efficiency
         local_efficiency = self.manager.dict()
-        self.measure_processes(local_efficiency, self.local_efficiency_kernel, 
+        self.measure_processes(local_efficiency, self.local_efficiency_kernel,
             nodal_efficiency)
         return local_efficiency
 
@@ -392,7 +388,7 @@ class ParallelGeneralGraph(GeneralGraph):
         betweenness_centrality = self.manager.dict()
         self.measure_processes(betweenness_centrality,
             self.betweenness_centrality_kernel, tot_shortest_paths_list)
-        
+
         return betweenness_centrality
 
     def compute_closeness_centrality(self):
